==> v1.16.7.zip: webinoly/README.md <==
<div align="center">
 	<p><a href="https://webinoly.com/"><img width="50%" src="https://cdn.qrokes.com/wp-content/uploads/sites/4/2020/11/webinoly_logo_blue.png" /></a></p>
 	<p>
		<img src="https://img.shields.io/badge/build-passing-brightgreen.svg" />
        <img src="https://img.shields.io/github/license/QROkes/webinoly" />
        <img src="https://img.shields.io/github/v/release/QROkes/webinoly?color=orange" />
	</p>
    <p><b>Optimized LEMP Web Server</b></br>
    <i>A powerful set of commands for doing just about anything you could wish.</i></p>
    <p><a href="https://webinoly.com/">Official Website</a> | <a href="https://webinoly.com/documentation/">Documentation</a> | <a href="https://github.com/QROkes/webinoly/releases">Changelog</a></p>
</div>

## Overview
A complete LEMP stack _– Linux Ubuntu + Nginx + MariaDB (MySQL) + PHP –_ or install individual packages according to your needs.

**One of the most reliable configurations to host your websites and with Webinoly you can do it in just one step.**

Webinoly provides a set of tools and commands that facilitate web server administration.
- Unique commands to create, delete, disable sites.
- Free SSL certificates for your sites with Let’s Encrypt and automatic server configuration.
- HTTP/2 dramatically increases the speed of serving your content.
- PHP v8.1 and support for earlier versions if needed (8.0 and 7.4).
- FastCGI Cache and Redis Object Cache for your WordPress sites.
- Install WP in any subfolder and support for external databases, multisite and domain mapping.
- Reverse Proxy for any app (Java, React, Node, Angular, Vue, etc) or to use your own domain with any external file repo like S3.
- A complete suite of tools for backups. Moving a site or the whole server has never been so easy.
- Protect your site, folder or file with HTTP Authentication.
- Advanced support for cloning your sites for testing.
- Custom FastCGI Cache support for any dynamic site.
- Nginx redirection manager, native SMTP for emails and a lot more features.
- Datadog native integration for monitoring and analytics.
- Get an A+ grade on [Qualys (SSL Labs) Test](https://www.ssllabs.com/ssltest/).
- Log viewer in real time.

## Usage

```bash
# Install Webinoly and LEMP
wget -qO weby qrok.es/wy && sudo bash weby

# Create your first site.
sudo site example.com -wp

# Authentication
sudo httpauth -add
```

### Requirements
* Ubuntu 22.04 or 20.04


### Documentation
For complete documentation, please [visit our site](https://webinoly.com/documentation/).


## Contributing
Please open an issue first to discuss what you would like to change.

You don't need developer skills to help, visit our site to know [How to Contribute to Webinoly](https://webinoly.com/en/contribute/).

### Donations

[![PayPal Donations](https://cdn.qrokes.com/media/paypal-webinoly-donate.png)](https://www.paypal.me/qrokes)
[![GitHub Sponsors](https://cdn.qrokes.com/media/github-sponsors.png)](https://github.com/sponsors/QROkes)
[![Bitcoin Donations](https://cdn.qrokes.com/media/bitcoin-webinoly-donate.png)](https://www.blockchain.com/en/btc/address/1E3Ybo5UcvaAr1MoK4nBnMRFFY9aEMiku3)

If you like Webinoly, buy me a coffee or a beer to show support.

**_Your regular donations keep this project moving forward._**

### Community
- Visit our [Community Forum](https://webinoly.com/support/)
- Follow [@Webinoly](https://twitter.com/Webinoly) on Twitter
- Subscribe to our [Newsletter](https://webinoly.com/newsletter/)

==> v1.17.0.zip: webinoly/README.md <==
<div align="center">
 	<p><a href="https://webinoly.com/"><img width="50%" src="https://cdn.qrokes.com/wp-content/uploads/sites/4/2020/11/webinoly_logo_blue.png" /></a></p>
 	<p>
		<img src="https://img.shields.io/badge/build-passing-brightgreen.svg" />
        <img src="https://img.shields.io/github/license/QROkes/webinoly" />
        <img src="https://img.shields.io/github/v/release/QROkes/webinoly?color=orange" />
	</p>
    <p><b>Optimized NGINX Web Server</b></br>
    <i>A powerful set of commands for doing just about anything you could wish.</i></p>
    <p><a href="https://webinoly.com/">Official Website</a> | <a href="https://webinoly.com/documentation/">Documentation</a> | <a href="https://github.com/QROkes/webinoly/releases">Changelog</a></p>
</div>

## Overview
A complete LEMP stack _– Linux Ubuntu + Nginx + MariaDB (or MySQL, you can choose) + PHP –_ or install individual packages according to your needs.

**One of the most reliable configurations to host your websites and with Webinoly you can do it in just one step.**

Webinoly provides a set of tools and commands that facilitate web server administration.
- Unique commands to create, delete, disable sites.
- Free SSL certificates for your sites with Let’s Encrypt and automatic server configuration.
- HTTP/2 dramatically increases the speed of serving your content.
- PHP v8.1 and support for earlier versions if needed (8.0 and 7.4) or the newest 8.2.
- FastCGI Cache and Redis Object Cache for your WordPress sites.
- Install WP in any subfolder and support for external databases, multisite and domain mapping.
- Reverse Proxy for any app (Java, React, Node, Angular, Vue, etc) or to use your own domain with any external file repo like S3.
- A complete suite of tools for backups. Moving a site or the whole server has never been so easy.
- Protect your site, folder or file with HTTP Authentication.
- Advanced support for cloning your sites for testing.
- Custom FastCGI Cache support for any dynamic site.
- Nginx redirection manager, native SMTP for emails and a lot more features.
- Datadog native integration for monitoring and analytics.
- Get an A+ grade on [Qualys (SSL Labs) Test](https://www.ssllabs.com/ssltest/).
- Log viewer in real time.

## Usage

```bash
# Install Webinoly and build the stack
wget -qO weby qrok.es/wy && sudo bash weby

# Create your first site.
sudo site example.com -wp

# Authentication
sudo httpauth -add
```

### Requirements
* Ubuntu 22.04 or 20.04


### Documentation
For complete documentation, please [visit our site](https://webinoly.com/documentation/).


## Contributing
Please open an issue first to discuss what you would like to change.

You don't need developer skills to help, visit our site to know [How to Contribute to Webinoly](https://webinoly.com/en/contribute/).

### Sponsors

<p><a href="https://www.eltris.com/" target="_blank" rel="sponsored nofollow noopener"><img width="250px" src="https://cdn.qrokes.com/wp-content/uploads/sites/4/2022/11/Sponsor_Eltris-European-Hosting_Logo.jpg" /></a></p>

### Donations

[![PayPal Donations](https://cdn.qrokes.com/media/paypal-webinoly-donate.png)](https://www.paypal.me/qrokes)
[![GitHub Sponsors](https://cdn.qrokes.com/media/github-sponsors.png)](https://github.com/sponsors/QROkes)
[![Bitcoin Donations](https://cdn.qrokes.com/media/bitcoin-webinoly-donate.png)](https://www.blockchain.com/en/btc/address/1E3Ybo5UcvaAr1MoK4nBnMRFFY9aEMiku3)

If you like Webinoly, buy me a coffee or a beer to show support.

**_Your regular donations keep this project moving forward._**

### Community
- Visit our [Community Forum](https://webinoly.com/support/)
- Follow [@Webinoly](https://twitter.com/Webinoly) on Twitter
- Subscribe to our [Newsletter](https://webinoly.com/newsletter/)
